@@ -29,6 +29,7 @@
 #include <algorithm>
 #include <cstddef>
 #include <cstdint>
+#include <cstdlib>
 #include <fstream>
 #include <iomanip>
 #include <iostream>
@@ -114,6 +115,9 @@ namespace pika::detail {
     {
         std::string mask_string = cfgmap.get_value<std::string>("pika.process_mask", "");
 
+        char const* mask_env = std::getenv("PIKA_PROCESS_MASK");
+        if (nullptr != mask_env) { mask_string = mask_env; }
+
         if (vm.count("pika:process-mask"))
         {
             mask_string = vm["pika:process-mask"].as<std::string>();
